;; -*- no-byte-compile: t; lexical-binding: nil -*-
(define-package "mastodon" "20251117.1458"
  "Client for fediverse services using the Mastodon API."
  '((emacs   "28.1")
    (persist "0.8")
    (tp      "0.7"))
  :url "https://codeberg.org/martianh/mastodon.el"
  :commit "1ac040c113c061c173206658657cdee708001471"
  :revdesc "1ac040c113c0"
  :authors '(("Johnson Denen" . "johnson.denen@gmail.com")
             ("Marty Hiatt" . "mousebot@disroot.org"))
  :maintainers '(("Marty Hiatt" . "mousebot@disroot.org")))
